Recent Supreme Court Slip Opinions - Alaska Court System
Description: Alaska Supreme Court Decisions
Keywords: Alaska Supreme Court, decisions, opinions, slip opinions, published opinions, Alaska, Court

Skip Navigation

# Alaska Court System

Home » Appellate Courts » Recent Supreme Court Slip Opinions

## Recent Supreme Court Slip Opinions

Opinions are removed from this site once they are printed in the Pacific Reporter, the designated official reporter of Alaskan appellate decisions. Opinions from 1960 to present can also be found in the law library's Alaska Case Law Service.

Supreme court slip opinions are subject to correction before publication in the Pacific Reporter. Please bring errors to the attention of:

Clerk of the Appellate Courts
303 K Street
Anchorage AK 99501
phone: 907-264-0608
fax: 907-264-0878
email: corrections@akcourts.us

See also:
Information about the appellate courts' opinion notification service
Case-Related Orders Issued by the Supreme Court

### 2015

#### July 24, 2015

- 7021 S-15370 Miller v. State, Dept. of Environmental Conservation
- 7022 S-15332 Pister v. State, Dept. of Revenue
- 7023 S-15636 McGee v. Alaska Bar Association
- 7024 S-15473 Ross v. Bauman

#### July 17, 2015

- 7019 S-15516 Jacko v. State
- 7020 S-15347 Ray v. Draeger

#### July 10, 2015

- 7018 S-15479 Hagen v. Strobel

#### July 2, 2015

- 7017 S-15281 Moore v. Olson

#### June 26, 2015

- 7016 S-15554 Cooper v. Thompson

#### June 19, 2015

- No opinions issued.

#### June 12, 2015

- 7015 S-15288 Sarah D. v. John D.

#### June 5, 2015

- 7014 S-15266 Hutton v. State

#### May 29, 2015

- 7011 S-14560/S-14579 Nunamta Aulukestai v. State, Dept. of Natural Resources
- 7012 S-15059/S-15060/S-15089 Alaska Conservation Foundation v. Pebble Limited Partnership, 350 P3d 273
- 7013 S-15712 Moore v. Moore, 349 P3d 1076

#### May 22, 2015

- No opinions issued.

#### May 15, 2015

- 7006 S-14752 Engstrom v. Engstrom
- 7007 S-15594 Ace Delivery & Moving, Inc. v. Alaska State Commission for Human Rights
- 7008 S-15121 Manning v. State, Dept. of Fish & Game
- 7009 S-15209 Devine v. Great Divide Insurance Company
- 7010 S-15513 Brandner v. Bateman, 349 P3d 1068

#### May 8, 2015

- No opinions issued.

#### May 1, 2015

- 7002 S-15450 In Re Ivy
- 7003 S-15222 Ranes & Shine, LLC v. MacDonald Miller Alaska, Inc.
- 7004 S-15581/S-15585 Payton S. v. State, Dept. of Health & Social Services, Office of Children's Services, 349 P3d 162
- 7005 S-15385 Vonder Haar v. State, Dept. of Administration, Division of Motor Vehicles, 349 P3d 173

#### April 24, 2015

- 7000 S-15419 Wagner v. State, 347 P3d 109
- 7001 S-15339 State, Dept. of Health & Social Services, Division of Public Assistance v. Gross, 347 P3d 116

#### April 17, 2015

- 6997 S-15566 Faye H. v. James B., 348 P3d 876
- 6998 S-15437 Kinnan v. Sitka Counseling, 349 P3d 153
- 6999 S-15364 Alaska Police Standards Council v. Parcell, 348 P3d 882

#### April 10, 2015

- 6996 S-15381 Castle Properties, Inc. v. Wasilla Lake Church of the Nazarene, 347 P3d 990

#### April 3, 2015

- 6994 S-15265 Patterson v. GEICO General Insurance Company, 347 P3d 562
- 6995 S-15045 Foondle v. O'Brien, 346 P3d 970

#### January - March 2015

- 6978 S-15217 RBG Bush Planes, LLC v. Kirk, 340 P3d 1056
- 6979 S-15472 Shirley M. v. State, Dept. of Health & Social Services, Office of Children's Services, 342 P3d 1233
- 6980 S-14947 Bush v. Elkins, 342 P3d 1245
- 6981 S-15468 Hughes v. Treadwell, 341 P3d 1121
- 6982 S-15067/S-15070 Moreno v. State, 341 P3d 1134
- 6983 S-15393 Goldsbury v. State, 342 P3d 834
- 6984 S-15586 Sylvia L. v. State, Dept. of Health & Social Services, Office of Children's Services, 343 P3d 425
- 6985 S-15582 In Re Estate of Bavilla, 343 P3d 905
- 6986 S-14856/S-14875 Alaska Fur Gallery, Inc. v. First National Bank Alaska, 345 P3d 76
- 6987 S-15240 Red Elk v. McBride, 344 P3d 818
- 6988 S-15341 Brooks v. Horner, 344 P3d 294
- 6989 S-14917 Stavenjord v. Schmidt, 344 P3d 826
- 6990 S-15354 Baker v. Ryan Air, Inc., 345 P3d 101
- 6991 S-15456 Mahan v. Mahan, 347 P3d 91
- 6992 S-14516 Alaska Fish and Wildlife Conservation Fund v. State, 347 P3d 97
- 6993 S-15439 Norris v. Norris, 345 P3d 924

Go to top of page | Return to Appellate Courts Homepage | Return to Court Homepage

### 2014

#### October - December 2014

- 6957 S-15346 Jamie H. v. State, Dept. of Health & Social Services, Office of Children's Services, 336 P3d 1253
- 6958 S-15212 Dodge v. Sturdevant, 335 P3d 510
- 6959 S-14963 Christensen v. Alaska Sales & Service, Inc., 335 P3d 514
- 6960 S-15140 Humphrey v. Lowe's Home Improvement Warehouse, Inc., 337 P3d 1174
- 6961 S-15172 Riggs v. Coonradt, 335 P3d 1103
- 6962 S-15314 Becker v. Fred Meyer Stores, Inc., 335 P3d 1110
- 6963 S-15163 Farmer v. Alaska USA Title Agency, Inc., 336 P3d 160
- 6964 S-15280 Villars v. Villars, 336 P3d 701
- 6965 S-15351 Chloe W. v. State, Dept. of Health & Social Services, Office of Children's Services , 336 P3d 1258
- 6966 S-14864/S-14883 Moody v. Royal Wolf Lodge, 339 P3d 636
- 6967 S-15318 Asa'carsarmiut Tribal Council v. Wheeler 337 P3d 1182
- 6968 S-14916 Brewer v. State, 341 P3d 1107
- 6969 S-15139 Resurrection Bay Auto Parts, Inc. v. Alder, 338 P3d 305
- 6970 S-15017 Garibay v. State, Dept. of Administration, Division of Motor Vehicles, 341 P3d 446
- 6971 S-15382 Green v. Parks, 338 P3d 312
- 6972 S-15166 State, Division of Workers' Compensation v. Titan Enterprises, LLC, 338 P3d 316

Go to top of page | Return to Appellate Courts Homepage | Return to Court Homepage

#### July - September 2014

- 6921 S-14488/S-15037 Girdwood Mining Company v. Comsult LLC, 329 P3d 194
- 6922 S-14865 Kristina B. v. Edward B., 329 P3d 202
- 6923 S-14945/S-15055 Lake & Peninsula Borough Assembly v. Oberlatz, 329 P3d 214
- 6924 S-14729 Schlumberger Technology Corp. & Subsidiaries v. State, Dept. of Revenue, 331 P3d 334
- 6925 S-15108 Grace L. v. State, Dept. of Health & Social Services, Office of Children's Services , 329 P3d 980
- 6926 S-14103 Simmonds v. Parks, 329 P3d 995
- 6927 S-15230 Harris v. Millennium Hotel, 330 P3d 330
- 6928 S-15087 Silver Bow Construction v. State, Dept. of Administration, Division of General Services , 330 P3d 922
- 6929 S-14782 Lane v. Ballot, 330 P3d 338
- 6933 S-15046 McCormick v. Chippewa, Inc., 330 P3d 345
- 6930 S-15355 Heber v. Heber, 330 P3d 926
- 6931 S-15088 Richter v. Richter, 330 P3d 984
- 6932 S-14910/S-14929 Donahue v. Ledgends, Inc., 331 P3d 342
- 6934 S-14713 Price v. Kenai Peninsula Borough, 331 P3d 356
- 6935 S-13978 Alaska Trustee, LLC v. Bachmeier, 332 P3d 1
- 6936 S-14495 Moffitt v. Moffitt, 341 P3d 1102
- 6937 S-15143 Blas v. State, Dept. of Labor, 331 P3d 363
- 6938 S-14874/S-14893 Alaska Judicial Council v. Kruse, 331 P3d 375
- 6939 S-15056 Pederson v. Arctic Slope Regional Corp., 331 P3d 384
- 6940 S-15034 Tweedy v. Matanuska-Susitna Borough Board of Adjustment and Appeals, 332 P3d 12
- 6941 S-14965 Greene v. Tinker, 332 P3d 21
- 6942 S-14736 Nautilus Marine Enterprises, Inc. v. Exxon Mobil Corporation & Exxon Shipping Co., 332 P3d 554
- 6943 S-15365 Grundberg v. Alaska State Commission for Human Rights, 333 P3d 1
- 6944 S-14857/S-14858/S-14897 Young v. Kelly, 334 P3d 153
- 6945 S-14960 In Re Protective Proceedings of Vernon H., 332 P3d 565
- 6946 S-15251 In Re Candace A., 332 P3d 578
- 6947 S-15006/S-15025 Adamson v. Municipality of Anchorage, 333 P3d 5
- 6948 S-14503/S-14524 Lee v. Konrad, 337 P3d 510
- 6949 S-15376 Sherry R. v. State, Dept. of Health & Social Services, Office of Children's Services , 332 P3d 1268
- 6950 S-15232 Houston v. Wolpert, 332 P3d 1279
- 6951 S-15218 Osborne v. State, Dept. of Corrections, 332 P3d 1286
- 6952 S-14969 Briggs v. City of Palmer, 333 P3d 746
- 6953 S-14776 Kanuk v. State, Dept. of Natural Resources, 335 P3d 1088
- 6954 S-14670 Native Village of Tununak v. State, Dept. of Health & Social Services, Office of Children's Services, 334 P3d 165
- 6955 S-15158 Graham R. v. Jane S., 334 P3d 688
- 6956 S-14492 Kyte v. Stallings, 334 P3d 697
- 6973 S-15374 Chung v. Park, 339 P3d 351
- 6974 S-15359 In Re Adoption of S.F., a Minor, 340 P3d 1045
- 6975 S-15366 In Re Miles, 339 P3d 1009
- 6976 S-15130/S-15219 Ebert v. Bruce L., 340 P3d 1048
- 6977 S-14884 Ellingson v. Lloyd, 342 P3d 825

Go to top of page | Return to Appellate Courts Homepage | Return to Court Homepage

#### April - June 2014

- 6886 S-14256 In Re Necessity for the Hospitalization of Gabriel C., 324 P3d 835
- 6887 S-14686/S-14775/S-14796 Rude v. Cook Inlet Region, Inc., 322 P3d 853
- 6888 S-14812 Hawkins v. Attatayuk, 322 P3d 891
- 6889 S-14759 Sandberg v. Sandberg, 322 P3d 879
- 6890 S-14987 Healy Lake Village v. Mt. McKinley Bank, 322 P3d 866
- 6891 S-14794 Regner v. North Star Volunteer Fire Dept., Inc., 323 P3d 16
- 6892 S-14476 Steward v. State, 322 P3d 860
- 6893 S-15207 Emma D. v. State, Dept. of Health & Social Services, Office of Children's Services, 322 P3d 842
- 6894 S-14770 Purcella v. Olive Kathryn Purcella Trust, 325 P3d 987
- 6895 S-14904 Kollander v. Kollander, 322 P3d 897
- 6896 S-14587 Mattox v. State, Dept. of Corrections, 323 P3d 23
- 6897 S-12944 Charles v. State, 326 P3d 978
- 6898 S-14521 State v. Schmidt, 323 P3d 647
- 6899 S-14820 Hendricks-Pearce v. State, Dept. of Corrections, 323 P3d 30
- 6900 S-14978 Alsworth v. Seybert, 323 P3d 47
- 6901 S-14887 Boulds v. Nielsen, 323 P3d 58
- 6902 S-14680 AAA Valley Gravel, Inc. v. Totaro, 325 P3d 529
- 6903 S-14701 State v. Public Safety Employees Association, 323 P3d 670
- 6904 S-14552 Lockwood v. Geico General Insurance Company, 323 P3d 691
- 6905 S-14853 Patterson v. Cox, 323 P3d 1118
- 6906 S-14718/S-14728/S-14737 BP Pipelines (Alaska) Inc. v. State, Dept. of Revenue, 327 P3d 185
- 6907 S-14881 Pralle v. Milwicz, 324 P3d 286
- 6908 S-15004 Davis Wright Tremaine LLP v. State, Dept. of Administration, 324 P3d 293
- 6909 S-14830 Achman v. State, 323 P3d 1123
- 6910 S-14194/S-14213 Conley v. Alaska Communications System Holdings, Inc., 323 P3d 1131
- 6911 S-14534 In Re Necessity for the Hospitalization of Mark V., 324 P3d 840
- 6912 S-15042 Yelena R. v. George R., 326 P3d 989
- 6913 S-15144 Brandner v. Municipality of Anchorage, 327 P3d 200
- 6914 S-15120 Louie v. BP Exploration (Alaska), Inc., 327 P3d 204
- 6915 S-14442 Pouzanova v. Morton, 327 P3d 865
- 6916 S-15160 Brown v. Personnel Board for the City of Kenai, 327 P3d 871
- 6917 S-15034 Tweedy v. Matanuska-Susitna Borough Board of Adjustment and Appeals - WITHDRAWN: See Op #6940
- 6918 S-15124 Frackman v. Enzor, 327 P3d 878
- 6919 S-14981 State, Dept. of Health & Social Services v. Mullins, 328 P3d 1038
- 6920 S-14557 Johnson v. State, 328 P3d 77

Go to top of page | Return to Appellate Courts Homepage | Return to Court Homepage

#### January - March 2014

- 6861 S-14822/S-14827/S-14924 Welton v. State, Dept. of Corrections, 315 P3d 1196
- 6862 S-15100 In Re Necessity for the Hospitalization of Daniel G., 320 P3d 262
- 6863 S-14938 Coppe v. Bleicher, 318 P3d 369
- 6864 S-14843 Sagers v. Sackinger, 318 P3d 860
- 6865 S-14896 Denali Citizens Council v. State, Dept. of Natural Resources, 318 P3d 380
- 6867 S-14095/S-14116/S-14125 BP Pipelines (Alaska) Inc. v. State, Dept. of Revenue, 325 P3d 478
- 6866 S-14891 McAlpine v. Priddle, 321 P3d 345
- 6868 S-14305 Christianson v. Conrad-Houston Insurance, 318 P3d 390
- 6869 S-15065 Stephanie W. v. Maxwell V., 319 P3d 219
- 6870 S-15149 Simone H. v. State, Dept. of Health & Social Services, Office of Children's Services, 320 Pd 284
- 6871 S-14357 Conitz v. Alaska State Commission for Human Rights, 325 P3d 501
- 6872 S-15128 James R. v. Kylie R., 320 P3d 273
- 6873 S-14750 Szabo v. Municipality of Anchorage, 320 P3d 809
- 6874 S-14654/S-14674/S-14953 ConocoPhillips Alaska, Inc. v. Williams Alaska Petroleum, Inc., 322 P3d 114
- 6875 S-14970 Limeres v. Limeres, 320 P3d 291
- 6876 S-14254/S-14262 Harris v. M-K Rivers, 325 P3d 510
- 6877 S-15076 Molly O. v. State, Dept. of Health & Social Services, Office of Children's Services, 320 P3d 303
- 6878 S-14989 Dennis v. State, Dept. of Administration, Division of Motor Vehicles, 320 P3d 1150
- 6879 S-14823/S-14863/S-14873 Alaska Community Action on Toxics v. Hartig, 321 P3d 360
- 6880 S-14753 Maness v. Gordon, 325 P3d 522
- 6881 S-15107 Rowan B. v. State, Dept. of Health & Social Services, Office of Children's Services, 320 P3d 1152
- 6882 S-14818 Shumway v. Betty Black Living Trust, 321 P3d 372
- 6883 S-15315 Municipality of Anchorage v. Holleman, 321 P3d 378
- 6884 S-14724 Zamarello v. Reges, 321 P3d 387
- 6885 S-14571/S-14931 Espeland v. OneWest Bank, FSB, 323 P3d 2

Go to top of page | Return to Appellate Courts Homepage | Return to Court Homepage